import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ActivatedRoute, Router } from '@angular/router';
import { AuthService } from '@service/auth.service';

@Component({
  selector: 'app-oauth2-callback',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div class="min-h-screen bg-deep-blue flex items-center justify-center">
      <div class="text-center">
        <h2 class="text-2xl font-bold text-white mb-4">Finishing authentication...</h2>
        <div
          class="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-emerald mx-auto"
        ></div>
        <p *ngIf="error" class="mt-4 text-accent-red">{{ error }}</p>
      </div>
    </div>
  `,
})
export class OAuth2CallbackComponent implements OnInit {
  error: string | null = null;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private authService: AuthService
  ) {}

  ngOnInit(): void {
    // Check for code in URL params
    this.route.queryParams.subscribe((params) => {
      const code = params['code'];
      const provider = this.route.snapshot.data['provider'] || 'github';

      if (code) {
        if (provider === 'google') {
          // Exchange Google code for a JWT token
          this.authService.googleAuth(code).subscribe({
            next: () => {
              // Redirect to home after successful authentication
              this.router.navigate(['/home']);
            },
            error: (err) => {
              console.error('Google authentication error:', err);
              this.error = err.error?.message || 'Authentication failed. Please try again.';
              console.log('Error details:', err);

              // Redirect back to landing page after showing error
              setTimeout(() => {
                this.router.navigate(['/']);
              }, 3000);
            },
          });
        } else {
          // Exchange GitHub code for a JWT token
          this.authService.githubAuth(code).subscribe({
            next: () => {
              // Redirect to home after successful authentication
              this.router.navigate(['/home']);
            },
            error: (err) => {
              console.error('GitHub authentication error:', err);
              this.error = err.error?.message || 'Authentication failed. Please try again.';
              console.log('Error details:', err);

              // Redirect back to landing page after showing error
              setTimeout(() => {
                this.router.navigate(['/']);
              }, 3000);
            },
          });
        }
      } else {
        this.error = 'Authentication failed. No authorization code received.';

        // Redirect back to landing page after showing error
        setTimeout(() => {
          this.router.navigate(['/']);
        }, 3000);
      }
    });
  }
}
